server {
    listen      %ip%:%web_port%;
    server_name %domain_idn% %alias_idn%;
    root        %docroot%;
    index       index.php index.html index.htm;
    access_log  /var/log/nginx/domains/%domain%.log combined;
    access_log  /var/log/nginx/domains/%domain%.bytes bytes;
    error_log   /var/log/nginx/domains/%domain%.error.log error;
	
	location / {
		proxy_send_timeout  300;
		proxy_read_timeout  300;
		proxy_connect_timeout  300;
		index index.php index.html index.htm;
		try_files $uri $uri/ /index.php?$query_string;
	}
	
	rewrite ^/templates/(.*) /public/view/templates/$1;
	
	location ~* ^.+\.(jpe?g|png|gif|svg|css|js|mp3|ogg|mpe?g|avi|swf|woff2|eot|woff|ttf)$ {
		if (-f $request_filename) {
			expires max;
			add_header Pragma public;
			add_header Cache-Control "public";
			break;
		}
		index index.php index.html index.htm;
		try_files $uri $uri/ /index.php?$query_string;
	}
	
    location /admin {
        try_files $uri /admin/index.php?$query_string;
    }
	
	location ~* "\/sys_tmp|^/ucontent|^/system\/|\/stats_tmp\/|\/_rezerv_images\/|\/cache\/|\.ini|(user)?macros\.xml$|\.lock|\.db|\/parsing_log\.txt|\/antivirus_md5\.txt|\.cfg|_client\.zip|\/browscap_cache\.php|\/templates\/.*\.(html|tpl|php|txt)|public\/view\/stats\/cloaking.js" {
		deny all;
		return 404;
	}

	location ~ [^/]\.php(/|$) {
		fastcgi_param SCRIPT_FILENAME $document_root$fastcgi_script_name;
		if (!-f $document_root$fastcgi_script_name) {
			return  404;
		}
		
		fastcgi_param PHP_ADMIN_VALUE "
			; realpath_turbo.open_basedir=/tmp/:/home/%user%/tmp/:/proc/meminfo:/proc/stat:%home%/%user%/web/%domain%/public_html/
			; sendmail_path=/usr/sbin/sendmail -t -i -fno-reply@%domain%
			; sendmail_from=no-reply@%domain%
		";
		
        fastcgi_pass    %backend_lsnr%;
        fastcgi_index   index.php;
        include         /etc/nginx/fastcgi_params;
		fastcgi_read_timeout 300;
		fastcgi_send_timeout 300;
		fastcgi_connect_timeout 300;
    }

	location = /favicon.ico {
		return 204;
		access_log     off;
		log_not_found  off;
	}

    error_page  403 /error/404.html;
    error_page  404 /error/404.html;
    error_page  500 502 503 504 /error/50x.html;

    location /error/ {
        alias   %home%/%user%/web/%domain%/document_errors/;
    }

    location ~* "/\.(htaccess|htpasswd)$" {
        deny    all;
        return  404;
    }
	
    location /vstats/ {
        alias   %home%/%user%/web/%domain%/stats/;
        include %home%/%user%/web/%domain%/stats/auth.conf*;
    }

    include     /etc/nginx/conf.d/phpmyadmin.inc*;
    include     /etc/nginx/conf.d/phppgadmin.inc*;
    include     /etc/nginx/conf.d/webmail.inc*;

    include     %home%/%user%/conf/web/nginx.%domain_idn%.conf*;
}
