server {
    listen      %ip%:%web_port%;
    server_name %domain_idn% %alias_idn%;
    root        %docroot%;
    index       client.php;
    access_log  /var/log/nginx/domains/%domain%.log combined;
    access_log  /var/log/nginx/domains/%domain%.bytes bytes;
    error_log   /var/log/nginx/domains/%domain%.error.log error;
	
	location / {
		proxy_send_timeout  300;
		proxy_read_timeout  300;
		proxy_connect_timeout  300;
		try_files $uri $uri/ /client.php?$query_string;
	}
	
	location ~ [^/]\.php(/|$) {
		fastcgi_param SCRIPT_FILENAME $document_root$fastcgi_script_name;
		if (!-f $document_root$fastcgi_script_name) {
			return  404;
		}
		
        fastcgi_pass    %backend_lsnr%;
        fastcgi_index   client.php;
        include         /etc/nginx/fastcgi_params;
		fastcgi_read_timeout 300;
		fastcgi_send_timeout 300;
		fastcgi_connect_timeout 300;
    }

	location = /favicon.ico {
		return 204;
		access_log     off;
		log_not_found  off;
	}

    error_page  403 /error/404.html;
    error_page  404 /error/404.html;
    error_page  500 502 503 504 /error/50x.html;

    location /error/ {
        alias   %home%/%user%/web/%domain%/document_errors/;
    }

    location ~* "/\.(htaccess|htpasswd)$" {
        deny    all;
        return  404;
    }
	
    location /vstats/ {
        alias   %home%/%user%/web/%domain%/stats/;
        include %home%/%user%/web/%domain%/stats/auth.conf*;
    }

    include     /etc/nginx/conf.d/phpmyadmin.inc*;
    include     /etc/nginx/conf.d/phppgadmin.inc*;
    include     /etc/nginx/conf.d/webmail.inc*;

    include     %home%/%user%/conf/web/nginx.%domain_idn%.conf*;
}
